/*********************************************************
	Crosswalk to Present
	
	----------------------------------
	
	Generates transition matrices going forward.
	Crosswalks values to present.
	
	NOTE: Requires Punjab Compiled - Quarterly to be updated.
	
*********************************************************/

clear all
set more off
set trace off
pause off
cap cd "$PAKTAX2_ANALYSIS"

**********************************

********************************
* SET QUARTER OF LATEST ANALYSIS
local ynow = 2016
local qnow = 1

********************************
			
* Generate paths
cap mkdir "Data/Cleaned Data/Administrative Data/Crosswalk/Transition Matrices/"
cap mkdir "Data/Cleaned Data/Administrative Data/Crosswalk/Transition Matrices/To Present"			

cap mkdir "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly"
cap mkdir "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis"

// Step 1: Generate transition matrices

forval y = 2008 / `ynow' {
	forval q = 1 / 4 {
		if (`y' < `ynow') | (`y' == `ynow' & `q' < `qnow') {

			// Next quarter and next year in a way that loops around
			local q2 = mod(`q', 4) + 1
			local y2 = `y' + int(`q' / 4)
			
			cap mkdir "Data/Cleaned Data/Administrative Data/Crosswalk/Transition Matrices/To Present//FY`y' Q`q'/"
			
			* Pull keys for the starting quarter
			use "Data/Cleaned Data/Administrative Data/Crosswalk/Keys//`y2'_q`q2'_keys.dta", clear
			keep if size_robust_partition > 1
			
			tempfile keys
			save `keys'
			
			qui count
			local N = `r(N)'
			
			* Skip if there's nothing to crosswalk
			if `N' == 0 continue
			
			
			* Loop through each of the robust partitions, and generate transitions
			forval i = 1/`N' {
				use `keys', clear
				keep in `i'
				
				levelsof robust_partition, local(rp)
				
				* Special case -- 800523 and 800524 in Q1 2014
				if `y2' == 2014 & `q2' == 1 & `rp' == 373 continue
			
				levelsof key1, local(circles) clean
				global circles = "`circles'"
				noi di "${circles}"
											
				* Loop over total
				foreach x in t {
				
					clear
			
					* Generate transition matrix
					do "Data/Do Files/Administrative Data/Make Transition Matrix.do" `q' `y' `x' 0

					clear
					svmat T
					
					* Truncate
					
					// Special case -- 403000 and 403100 property transfer
					* This is a two way switch, so no truncation
					if `q' == 2 & `y' == 2010 & `rp' == 123 {
						di "Pass"
					}
					else {
					
						local truncate = 0
						
						foreach var of varlist T* {
						
							count if `var' < 0 | (`var' > 1 & `var' < .)
							local n = `r(N)'
							
							* In case of truncation, save the not-truncated copies and add to truncated list
							if `n' > 0 & `truncate' == 0 {
								save "Data/Cleaned Data/Administrative Data/Crosswalk/Transition Matrices/To Present//FY`y' Q`q'/rp`rp'_`x'_notrounded.dta", replace
								
								preserve
									clear
									set obs 1
									gen fyear = `y'
									gen qtr = `q'
									gen rp = `rp'
									gen margin = "t"
									gen direction = "Forward"
									
									cap append using "Data/Cleaned Data/Administrative Data/Crosswalk/Truncated"
									duplicates drop
									save "Data/Cleaned Data/Administrative Data/Crosswalk/Truncated", replace
								restore

								local truncate = 1

							}
							
							replace `var' = 0 if `var' < 0
							replace `var' = 1 if `var' > 1 & `var' < .
							
						}
					}
					
					save "Data/Cleaned Data/Administrative Data/Crosswalk/Transition Matrices/To Present//FY`y' Q`q'/rp`rp'_`x'.dta", replace
				
				}
			
			}
					
		}
	}
}


* Special case RP 373 in Q4 2013
do "Data/Do Files/Administrative Data/RP373 Transition Matrix.do"

* Special case RP 315 in Q2 2015
do "Data/Do Files/Administrative Data/RP315 Transition Matrix.do"

// Step 2 : Update all variables based on these matrices

use "Data/Cleaned Data/Administrative Data/Quarterly/FY2008 Q1/FY2008 Q1.dta", clear

keep circle_id net_dem* gross_dem* recov_tot* 
drop *_t

foreach var of varlist net_dem* gross_dem* recov_tot* {
	rename `var' q1_2008_`var'
}

save "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis//2008_q1_crosswalk.dta", replace
 
mata
	real matrix function crosswalk(T) {
		a0 = st_data(., 2)
		a0_xw = T * a0
		return(a0_xw)
	}
end

mata
	void savevalues(a0_xw, V) {
		updatevar = V
		st_addvar("double", updatevar)
		st_store(., updatevar, a0_xw)
	}
end

forval y=2008 / `ynow' {
	forval q=1/4 {
		if (`y' < `ynow') | (`y' == `ynow' & `q' < `qnow') {

		// Next quarter and next year in a way that loops around
		local q2 = mod(`q', 4) + 1
		local y2 = `y' + floor(`q' / 4)
		
		// Save out current data
		use "Data/Cleaned Data/Administrative Data/Quarterly/FY`y2' Q`q2'/FY`y2' Q`q2'.dta", clear		
		keep circle_id net_dem* gross_dem* recov_tot* 
		drop *_t
		foreach var of varlist net_dem* gross_dem* recov_tot* {
			rename `var' q`q2'_`y2'_`var'
		}
		save "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis//`y2'_q`q2'_crosswalk.dta", replace
		
		
		* Pull circles that don't need to be crosswalked, save out
		use "Data/Cleaned Data/Administrative Data/Crosswalk/Keys//`y2'_q`q2'_keys.dta", clear
		keep if size_robust_partition == 1
			
		keep key1
		rename key1 circle_id
		split circle_id, p(",") destring

		drop circle_id

		gen i = _n

		reshape long circle_id, i(i) j(j)
		drop if missing(circle_id)

		keep circle_id
			
		merge 1:1 circle_id using "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis//`y'_q`q'_crosswalk.dta"
		keep if _merge == 3
		drop _merge
		
		merge 1:1 circle_id using "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis//`y2'_q`q2'_crosswalk.dta", nogenerate
		save "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis//`y2'_q`q2'_crosswalk.dta", replace		
			
		use "Data/Cleaned Data/Administrative Data/Crosswalk/Keys//`y2'_q`q2'_keys.dta", clear
		keep if size_robust_partition > 1
			
		tempfile keys
		save `keys'
			
		qui count
		local N = `r(N)'
			
		* Skip if there's nothing to crosswalk
		if `N' == 0 continue
	
		* Loop through each of the robust partitions, and generate transitions
		forval i = 1/`N' {
			use `keys', clear
			keep in `i'

			levelsof key1, local(circles) clean
			pause
				
			levelsof key2, local(circles2) clean
			levelsof robust_partition, local(rp) clean
					
			use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis//`y'_q`q'_crosswalk.dta", clear
			keep if inlist(circle_id, `circles')
			tempfile data
			save `data'
		
			foreach x in c a {

				use "Data/Cleaned Data/Administrative Data/Crosswalk/Transition Matrices/To Present//FY`y' Q`q'//rp`rp'_t.dta", clear
				mkmat T*, matrix(T)
				mata : T = st_matrix("T")
				
				clear
			
				// Second loop -- update loop
				forval y_update = 2008/`y' {
					forval q_update = 1/4 {
						if (`y_update' < `y') | (`y_update' == `y' & `q_update' <= `q') {
		
							// Next quarter and next year in a way that loops around
							local q_update2 = mod(`q_update', 4) + 1
							local y_update2 = `y_update' + floor(`q_update' / 4)

							foreach var in net_dem gross_dem recov_tot {

								use `data', clear
								keep circle_id q`q_update'_`y_update'_`var'_`x'
								mata : a0_xw = crosswalk(T)					
								mata : a0_xw
				
								use "Data/Cleaned Data/Administrative Data/Quarterly/FY`y2' Q`q2'/FY`y2' Q`q2'.dta", clear
								keep if inlist(circle_id, `circles2')
								keep circle_id
				
								mata : savevalues(a0_xw, "q`q_update'_`y_update'_`var'_`x'")
				
								tempfile overwrite
								save `overwrite'
							
								// Overwrite with new data
								use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis//`y2'_q`q2'_crosswalk.dta", clear
								merge 1:1 circle_id using `overwrite', update replace nogenerate
								save "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis//`y2'_q`q2'_crosswalk.dta", replace
								
							}
						}
					}	
				}
			}
		}
		
		// Clean up
		use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis//`y2'_q`q2'_crosswalk.dta", clear
		
		foreach var of varlist *net_dem* *gross_dem* *recov_tot* {
			replace `var' = round(`var') 
		}
		
		save "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis//`y2'_q`q2'_crosswalk.dta", replace
		
		// Handle special cases
		do "Data/Do Files/Administrative Data/Crosswalk to Present - Special Cases.do" `y2' `q2' "To Present - Analysis"
		
		}
	}
}

