* Contains helper functions used for making the
* transition matrix and saving results to a dataset.

* For information about the logic of these files, see
* the Crosswalk Readme in the Documentation folder.

mata : mata clear
set more off

mata
	real matrix function makeM0(m, n, k) {
	
		// Set up M0
		M0 = J(m, n, 0)
		
		for (i=1; i <= n; i++) {
		
			splitcount = _st_data(i, 1)
			finalsplit = _st_data(i, 2)
			
			for (j=1; j <= m; j++) {
				
				involved = _st_data(i, j + 2)

				// Case 1 -- Merge, fully absorbed
				if (splitcount == 1 & involved == 1) M0[j, i] = 1
				
				// Case 2 -- Split, final circle
				if (splitcount > 1 & involved == 1 & j == finalsplit) M0[j, i] = 1
			}
		}
		
		return(M0)
	}
end

mata
	real matrix function makeM(m, n, k) {
		// Set up M1 through Mk in one large M matrix
		
		M = J(m, k * n, 0)
		matrixcount = 0
		
		for (i=1; i <= n; i++) {
			circlecount = _st_data(i, 1)
				
			if (circlecount > 1) {
				finalsplit = _st_data(i, 2)
					
				for (j=1; j <= m; j++) {
					involved = _st_data(i, j + 2)
						
					// Case 1 -- splitting, not final split
					if (involved == 1 & j < finalsplit) {
						M[j, i + matrixcount * n] = 1
					}
						
					// Case 2 -- splitting,  final split
					if (involved == 1 & j == finalsplit) {
						M[j, i + matrixcount * n] = -1
						matrixcount = matrixcount + 1
					}
				}
			}
		}
		
		return(M)
	}
	
end


mata
	real matrix function makeMv2(m, n, k) {
		// Set up M1 through Mk in one large M matrix
		
		M = J(m, k * n, 0)
		matrixcount = 0
		
		for (i=1; i <= n; i++) {
			circlecount = _st_data(i, 1)
			
			if (circlecount > 1) {
				finalsplit = _st_data(i, 2)
				usedindices = 0
				skip = 0
				
				// This loop is necessary in case a circle goes through more than one split
				// in which case we need to make sure we're distributing the alphas
				// across multiple matrices
				for (k0=2; k0<=circlecount; k0++) {
				
					for (j=1; j <= m; j++) {
						involved = _st_data(i, j + 2)
						
						//Check if used index
						used = sum(usedindices :== j)
						
						// Case 1 -- splitting, not final split
						if (involved == 1 & j < finalsplit & used == 0 & skip == 0) {
							M[j, i + matrixcount * n] = 1
							usedindices = usedindices, j
							skip = 1
						}
						
						// Case 2 -- splitting,  final split
						if (involved == 1 & j == finalsplit) {
							M[j, i + matrixcount * n] = -1
							matrixcount = matrixcount + 1
							skip = 0
						}
					}
				}
			}
		}
		
		return(M)
	}
	
end
	
mata
	void calculateT(real scalar n, real scalar k, real matrix M0, real matrix M, real matrix a, real matrix b, real matrix T) {

		beta = colsum(b) / colsum(a)
		inverse_beta = 1 / beta
			
		// Use the equation, rhs = 1 / beta * b - M0 * a
		rhs = inverse_beta * b - M0 * a
		
		// Construct left hand side of equation
		for (i = 1; i <= k; i++) {
			start = (i-1) * n + 1
			finish = i * n
			lhs_temp = M[., start::finish] * a
			
			if (i == 1) lhs = lhs_temp
			if (i > 1) lhs = lhs, lhs_temp
		}
						
		// Solve for the parameter
		alpha = svsolve(lhs, rhs)
			
		// Construct transition matrix
		T = M0
		
		for (i = 1; i <= k; i++) {
			start = (i-1) * n + 1
			finish = i * n
			T_temp = alpha[i, 1] * M[., start::finish]
			
			T = T + T_temp
		}
	}
end

// Requires data to be crosswalked to be stored in the second column.
mata
	real matrix function crosswalk(T) {
		a0 = st_data(., 2)
		a0_xw = T * a0
		return(a0_xw)
	}
end

mata
	void savevalue(a0_xw, updatevar) {
		st_addvar("long", updatevar)
		st_store(., updatevar, a0_xw)
	}
end
