/*
Prepares dataset for use in baseline preferences regressions

Authors:
	Ismail Khan (2015-)

Date created:
	December 2, 2015
	
Notes:
	- We drop any preference sheets where any ranking is missing (even if ranking is partially completed)
	- Some inspectors submitted two distinct preference sheets for the same group. We only pick one and stick with it.

Special note on inspector 40838
	Inspector 40838 was believed to be in 402700 at the time of baseline, so 402700 was 
	included in GUJRANWALA group 5. However, inspector 40838 was actually in 402800 at
	the time. We thus have 40838's preferences, but for the wrong group (402700 instead
	of 402800). We ignore both 402700 and 402800 when computing own circle rank, but we
	use 402700's preference to compute average circle rank. We also only use 402800 when
	calculating avg circle rank.
	
*/

******************************************************************************
* Initial setup
******************************************************************************

clear all
set more off
pause on
cap cd "$PAKTAX2_ANALYSIS"

* Declare variables used throughout file
local num_y1_circles = 410
local num_missing_treat_rankings = 2
local num_missing_contr_rankings = 27

* Declare input files
local y2_analysis_data =  			"TP Analysis/Coded Data/TP Y2 Analysis Data w Y1 Treatment.dta"
local pilot_list1 = 				"Data\Randomization\Output\Year 1/130803 Multan PILOT Transfers Randomization Output MERGE 51135.dta"
local pilot_list2 = 				"Data\Randomization\Output\Year 1/130726 Lahore PILOT Transfers Randomization Output MERGE 150.dta"
local base_pref_file = 				"Data/Cleaned Data/Preference Data/150605 Compiled Preference Data"

* Declare output files
local analysis_output =				"TP Analysis/Coded Data/Baseline Preferences analysis data"
local analysis_output_tr =			"TP Analysis/Coded Data/Treatment Baseline Preferences for Analysis"
local base_pref_output = 			"TP Analysis/Coded Data/Cleaned baseline preferences"
local base_pref_output_tr = 		"TP Analysis/Coded Data/Treatment Baseline Preferences for Analysis complete"
local ins_analysis_output = 		"TP Analysis/Coded Data/Baseline Preferences Inspector analysis data"


******************************************************************************
* Dataset prep
******************************************************************************

* Save list of circles in pilot (might not use this later)
use "`pilot_list1'", clear
append using "`pilot_list2'"
keep circle_id
isid circle_id
tempfile pilot_circles
sa `pilot_circles'

* Used to verify that preference list contains the right circles
use "`y2_analysis_data'", clear
keep if treatment_y1 == 1
keep circle_id hr_id
duplicates drop
tempfile y1_treat_list
sa `y1_treat_list'


******************************************************************************
* Load and prep baseline preferences
******************************************************************************

use "`base_pref_file'", clear

* Remove pilot circles
merge m:1 circle_id using `pilot_circles'
keep if _m == 1
drop _m

* Modify preference data (some own_hr_ids are missing): note that this does not apply to any treatment circles, so we're OK
replace own_hr_id = 81027 if partition_name == "MULTAN" & group == 6 & mi(own_hr_id)
replace own_hr_id = 31260 if partition_name == "SARGODHA" & group == 2 & mi(own_hr_id)
replace own_hr_id = 31161 if partition_name == "FAISALABAD" & group == 5 & (own_hr_id == 33000 | mi(own_hr_id))
replace own_hr_id = 61013 if partition_name == "LAHORE" & group == 12 & mi(own_hr_id)
replace hr_id = 61013 if partition_name == "LAHORE" & group == 12 & circle_id == 611602
replace own_hr_id = 60144 if partition_name == "LAHORE" & group == 2 & mi(own_hr_id)
replace own_hr_id = 61007 if partition_name == "LAHORE" & group == 4 & mi(own_hr_id)
bys partition_name group own_hr_id hr_id: egen seq = seq() // Tagged because groups below have two missing pref sheets
replace own_hr_id = 61009 if partition_name == "LAHORE" & group == 8 & mi(own_hr_id) & seq == 1
replace own_hr_id = 81072 if partition_name == "LAHORE" & group == 8 & mi(own_hr_id) & seq == 2
replace own_hr_id = 60226 if partition_name == "LAHORE" & group == 10 & mi(own_hr_id) & seq == 1
replace own_hr_id = 50095 if partition_name == "LAHORE" & group == 10 & mi(own_hr_id) & seq == 2
drop seq

drop own_circle // variable is not accurate
gen own_circle = 1 if own_hr_id == hr_id

* Test: Check num of missing pref sheets, and total number of circles
preserve
	keep if own_circle == 1
	keep circle_id ranking treatment
	duplicates drop circle_id, force
	count
	assert `r(N)' == `num_y1_circles'
	count if mi(ranking) & treatment == 0
	assert `r(N)' == `num_missing_contr_rankings'
	count if mi(ranking) & treatment == 1 
	assert `r(N)' == `num_missing_treat_rankings'
restore

drop if missing(own_hr_id) // Drop circles with no inspector

* Test: Ensure that every inspector has at least one "own_circle"
preserve
	egen has_own_circle = total(own_circle), by(partition_name group own_hr_id)
	assert has_own_circle >= 1 // This isn't exactly == 1 because sometimes an inspector puts his additional charge in the list of preferences
restore

* Test: Ensure that inspectors have not submitted >1 distinct preferences for the same group
preserve
	keep partition_name group own_hr_id ranking circle_id
	duplicates drop
	duplicates tag partition_name group own_hr_id circle_id, gen(d)
	*assert !d
restore

rename hr_id circle_hr_id
rename own_hr_id hr_id

* Create own_circle_id variable
gen own_circle_id_temp = circle_id if own_circle == 1
egen own_circle_id = max(own_circle_id_temp), by(partition_name group hr_id)
drop own_circle_id_temp

* Remove unnecessary variables
keep partition_name group hr_id ranking circle_id own_circle treatment
duplicates drop

* TEMPORARY MEASURE: keep only one preference sheet for inspectors with >1 preference sheets
drop if hr_id == 11661 		& circle_id == 108101 	& ranking == 2
drop if hr_id == 11661 		& circle_id == 107800 	& ranking == 3
drop if hr_id == 11661 		& circle_id == 107700 	& ranking == 4
drop if hr_id == 11661 		& circle_id == 100200 	& ranking == 5
drop if hr_id == 11661 		& circle_id == 108300 	& ranking == 7
drop if hr_id == 11661 		& circle_id == 108000 	& ranking == 8
drop if hr_id == 11511 		& circle_id == 101200 	& ranking == 1
drop if hr_id == 11511 		& circle_id == 101300 	& ranking == 2
drop if hr_id == 11511 		& circle_id == 102100 	& ranking == 3
drop if hr_id == 11511 		& circle_id == 100701 	& ranking == 4
drop if hr_id == 11511 		& circle_id == 107200 	& ranking == 6
drop if hr_id == 11511 		& circle_id == 107902 	& ranking == 7
drop if hr_id == 11511 		& circle_id == 107600 	& ranking == 8
drop if hr_id == 11511 		& circle_id == 109100 	& ranking == 9
drop if hr_id == 11511 		& circle_id == 109000 	& ranking == 10
drop if hr_id == 11511 		& circle_id == 105600 	& ranking == 11
drop if hr_id == 11671 		& circle_id == 107600 	& ranking == 1
drop if hr_id == 11671 		& circle_id == 107200 	& ranking == 2
drop if hr_id == 11671 		& circle_id == 107902 	& ranking == 5
drop if hr_id == 11671 		& circle_id == 101200 	& ranking == 6
drop if hr_id == 11671 		& circle_id == 100701 	& ranking == 7
drop if hr_id == 11671 		& circle_id == 101300 	& ranking == 8
drop if hr_id == 11671 		& circle_id == 101800 	& ranking == 9
drop if hr_id == 11671 		& circle_id == 105600 	& ranking == 10
drop if hr_id == 11671 		& circle_id == 102100 	& ranking == 11
drop if hr_id == 81201 		& circle_id == 808700 	& ranking == 1
drop if hr_id == 81201 		& circle_id == 808800 	& ranking == 2
drop if hr_id == 112542 	& circle_id == 1101400 	& ranking == 1
drop if hr_id == 112542 	& circle_id == 1100713 	& ranking == 2
drop if hr_id == 112542 	& circle_id == 1100900 	& ranking == 3

* Test: Ensure that inspectors have not submitted >1 distinct preferences for the same group
preserve
	duplicates tag partition_name group hr_id circle_id, gen(d)
	keep partition_name group hr_id ranking circle_id
	duplicates drop
	duplicates tag partition_name group hr_id circle_id, gen(d)
	assert !d
	drop d
restore

tempfile preferences
sa `preferences'


******************************************************************************
* Normalize rankings
******************************************************************************

use `preferences', clear

* Normalize all rankings
bys partition_name group hr_id: egen rank_count = count(ranking)
bys partition_name group hr_id: egen max_rank = max(ranking)
assert max_rank == rank_count if rank_count > 0
gen norm_ranking = 1 + ( ((ranking-1)/(rank_count-1)) * (10-1) ) if rank_count > 0
drop rank_count max_rank


******************************************************************************
* Create column for u1
******************************************************************************

* Count number of inspectors per group
bys partition_name group hr_id: gen hr_counter = _n == 1
bys partition_name group: egen num_ins_in_group = total(hr_counter)
drop hr_counter

* Calculate u1
bys partition_name group hr_id (norm_ranking): gen u1 = 1 - ( (_n-1) / (num_ins_in_group-1) ) if !mi(ranking)
replace u1 = 0 if u1 < 0 // These are circles where it is impossible for the inspector to be posted

sa "`base_pref_output'", replace

preserve
drop u1
keep if treatment==1
sa "`base_pref_output_tr'", replace
restore 

******************************************************************************
* Drop missing rankings
******************************************************************************

bys partition_name group hr_id: gen missing_ranking = mi(ranking)
bys partition_name group hr_id: egen any_missing_ranking = max(missing_ranking)
drop if any_missing_ranking
assert !mi(ranking)
drop any_missing_ranking missing_ranking


******************************************************************************
* Create LHS variables for analysis
******************************************************************************

gen ranked_first = ranking == 1
collapse (sum) num_ranked_first=ranked_first (count) num_rankings=ranking (mean) average_ranking=norm_ranking average_u1=u1 (first) treatment, by(circle_id)
gen fraction_ranked_first = num_ranked_first / num_rankings
assert fraction_ranked_first <= 1
drop num_ranked_first num_rankings

label var fraction_ranked_first "Fraction ranked first"
label var average_ranking "Average ranking"
label var average_u1 "Average u1"

******************************************************************************
* Save dataset
******************************************************************************

save "`analysis_output'", replace

keep if treatment==1
save "`analysis_output_tr'", replace

