/*
Find the time in the circle as of end of Y2 Q3 for every inspector

Author(s):
	Ismail Khan (2015-)
	
Date created:
	Jun 9, 2016
*/


******************************************************************************
* 0. Initial setup
******************************************************************************

clear all
set more off
cap cd "$PAKTAX2_ANALYSIS"

* Declare constants here
local q_latest = 					3
local y_latest = 					2015
local y_prev = 						2014
local days_in_qtr 					92		92		90		91
local q_day_start 					1		1		1	 	1
local q_day_end 					30	 	31	 	31	 	30
local q_month_start 				7	 	10	 	1	 	4
local q_month_end 					9 		12 		3 		6
local q_year2015 					2014	2014 	2015 	2015
local q_year2014 					2013	2013	2014	2014

* Declare input files here
local hr_q1_2014_file = 			"Data/Raw Data/Current HR Confirmation/131028 HR Verification FY2014Q1/140709 HR Verification Q1 Inspectors.csv"
local hr_q2_2014_file = 			"Data/Raw Data/Current HR Confirmation/140414 HR Verification FY2014 Q2-Q3/140709 HR Verification Q2 Inspectors.csv"
local hr_q3_2014_file = 			"Data/Raw Data/Current HR Confirmation/140414 HR Verification FY2014 Q2-Q3/140709 HR Verification Q3 Inspectors.csv"
local hr_q4_2014_file = 			"Data/Raw Data/Current HR Confirmation/140630 HR Verification FY2014 Q4/140717 HR Verification Q4.csv"
local hr_q1_2015_file = 			"Data/Raw Data/Current HR Confirmation/140915 HR Verification FY2015 Q1 - Ballot/150109 HR Verification Q1.csv"
local hr_q2_2015_file = 			"Data/Raw Data/Current HR Confirmation/150114 HR Verification FY2015 Q2/150216 HR Verification Q2.csv"
local hr_q3_2015_file = 			"Data/Raw Data/Current HR Confirmation/150301 HR Verification FY2015 Q3/150512 HR Verification Q3.csv"
local hr_q4_2015_file = 			"Data/Raw Data/Current HR Confirmation/150629 HR Verification FY2015 Q4/150827 HR Verification Q4.csv"
local crosswalk_all = 				"Data/Raw Data/Administrative Data/120904 Crosswalk to Randomization_All.csv"
local y2_analysis_file = 			"TP Analysis/Coded Data/TP Y2 Analysis Data"
local y1_analysis_file = 			"TP Analysis/Coded Data/150525 TP Analysis Data"

* Declare output files here
local output_file = 				"TP Analysis/Coded Data/Time in Circle as of Y2 Q3"


******************************************************************************
* 1. Load HR data
******************************************************************************

forval y = 2014/2015 {
	forval q = 1/4 {

		if !(`y' == 2015 & `q' == 4) {
	
			* Load file corresponding to quarter & year
			insheet using "`hr_q`q'_`y'_file'", comma clear
			
			/*
			Apply basic data cleaning
			*/
			drop if mi(circle_id)

			* Ensure that hr ID is not missing if circle is not vacant
			assert !mi(hr_id1) if ins1 != "" & ins1 != "VACANT"
			assert !mi(hr_id2) if ins2 != "" & ins2 != "VACANT"
			
			cap confirm hr_id3
			if !_rc {
				assert !mi(hr_id3) if ins3 != "" & ins3 != "VACANT"
			}
				
			* Convert start* and end* to string vars
			tostring start*, replace
			tostring end*, replace
			replace start1 = "" if mi(start1) | start1 == "."
			replace start2 = "" if mi(start2) | start2 == "."
			cap confirm start3
			if !_rc {
				replace start3 = "" if mi(start3) | start3 == "."
			}
			replace end1 = "" if mi(end1) | end1 == "."
			replace end2 = "" if mi(end2) | end2 == "."
			cap confirm end_3
			if !_rc {
				replace end3 = "" if mi(end3) | end3 == "."
			}
			
			keep hr_id* start* end* circle_id* inspector
			
			gen qtr = `q'
			gen fyear = `y'
			
			tempfile hr_q`q'_`y'
			save `hr_q`q'_`y''
		}
	}
}

* Fix errors
use `hr_q3_2015', clear
foreach var in hr_id3 {
	replace `var' = . if circle_id == 509000
}
foreach var in start3 end3 {
	replace `var' = "" if circle_id == 509000
}
sa `hr_q3_2015', replace

use `hr_q1_2015', clear
foreach var in hr_id1 {
	replace `var' = . if circle_id == 609400
}
foreach var in start1 end1 {
	replace `var' = "" if circle_id == 609400
}
sa `hr_q1_2015', replace

use `hr_q4_2014', clear
foreach var in hr_id1 {
	replace `var' = . if circle_id == 612900
	replace `var' = . if inlist(circle_id, 100601, 100602)
}
foreach var in start1 end1 {
	replace `var' = "" if circle_id == 612900
	replace `var' = "" if inlist(circle_id, 100601, 100602)
}
replace end1 = "09.04.2014" 	if inlist(circle_id, 100601, 100602)
replace start2 = "09.04.2014" 	if inlist(circle_id, 100601, 100602)
replace start2 = "" 			if circle_id == 403710
replace hr_id3 = 40874 			if circle_id == 403710
drop 							if circle_id == 403720
save `hr_q4_2014', replace

use `hr_q3_2014', clear
foreach var in hr_id1 {
	replace `var' = . if circle_id == 1104400
}
foreach var in start1 end1 {
	replace `var' = "" if circle_id == 1104400
}
sa `hr_q3_2014', replace


******************************************************************************
* 2. Apply data checks for each quarter
******************************************************************************

/*
Check 1: Make sure that the HR files are exhaustive (i.e. contain all circles)
*/
forval y = 2014/2015 {
	forval q = 1/4 {
		if !(`y' == 2015 & `q' == 4) {
		
			* Load list of all circles
			insheet using "`crosswalk_all'", comma clear
			keep q`q'_`y'_circle_id
			ren q`q'_`y'_circle_id circle_id
			drop if missing(circle_id)
			duplicates drop
			
			di "HI"
			di `q'
			di `y'
			* Ensure perfect merge with quarterly HR
			merge 1:m circle_id using `hr_q`q'_`y'', assert(1 3) keep(match) // nogen
		}
	}
}


/*
Check 2: Make sure there is continuity between quarters
*/
forval y = 2014/2015 {

	* Loop from Q1 to <quarter before q_latest> 2015
	forval q = 1/3 {
		
		if !(`y' == 2015 & `q' == 3) {
			local q_next = `q' + 1

			* List of crosswalked circles, using Q circle IDs
			insheet using "`crosswalk_all'", comma clear
			keep if q`q'_`y'_circle_id != q`q_next'_`y_latest'_circle_id
			keep q`q'_`y'_circle_id
			drop if mi(q`q'_`y'_circle_id)
			ren q`q'_`y'_circle_id circle_id
			duplicates drop
			tempfile q`q'_`y'_crosswalked_circles
			sa `q`q'_`y'_crosswalked_circles'

			* List of crosswalked circles, using Q+1 circle IDs
			insheet using "`crosswalk_all'", comma clear
			keep if q`q'_`y'_circle_id != q`q_next'_`y_latest'_circle_id
			keep q`q_next'_`y'_circle_id
			drop if mi(q`q_next'_`y'_circle_id)
			ren q`q_next'_`y'_circle_id circle_id
			duplicates drop
			tempfile q`q_next'_`y'_crosswalked_circles
			sa `q`q_next'_`y'_crosswalked_circles'
			
			* Now, load HR for current Q
			use `hr_q`q'_`y'', clear
			keep if inspector == 1
			keep circle_id hr_id* start* end* qtr

			* Keep only the last inspector in each circle
			di `y'
			di `q'
			reshape long hr_id start end, i(circle_id) j(j)
			drop if hr_id == .
			egen maxj = max(j), by(circle_id)
			keep if j == maxj
			rename hr_id hr_id1

			* Add Q+1 HR
			merge 1:1 circle_id hr_id1 using `hr_q`q_next'_`y''
			keep if inspector == 1
			gen hr_matched = _m == 3
			drop _m

			* Tag crosswalked circles
			merge m:1 circle_id using `q`q'_`y'_crosswalked_circles'
			gen crosswalked = _m == 3
			drop _m
			merge m:1 circle_id using `q`q_next'_`y'_crosswalked_circles'	
			replace crosswalked = crosswalked == 1 | _m == 3
			drop _m
				
			* Final check for continuity (no need to check for crosswalked circles)
			assert hr_matched == 1 if end == "" & qtr == `q' & !crosswalked
		}
	}
}


/*
Check 3: 
	- Make sure that if an inspector is in two circles at 1 time, then the ins_ac field is filled
	- Make sure that start/end falls inside relevant quarter
*/
forval y = 2014/2015 {
	forval q = 1/4 {

		if !(`y' == 2015 & `q' == 4) {
			* Declare relevant dates for each quarter
			local q_d_start:	word `q' of `q_day_start'
			local q_d_end: 		word `q' of `q_day_end'
			local q_m_start:	word `q' of `q_month_start'
			local q_m_end:		word `q' of `q_month_end'
			local q_yr:			word `q' of `q_year`y''
			
			* Load HR data
			use `hr_q`q'_`y'', clear
			keep if inspector == 1
			reshape long hr_id ins ins_ac start end, i(circle_id) j(j)
			drop if mi(hr_id)

			* Fill in blank entries in start and end
			replace start = "`q_d_start'.`q_m_start'.`q_yr'" if inlist(start, "", ".")
			replace end = "`q_d_end'.`q_m_end'.`q_yr'" if inlist(end, "", ".")
			
			* Convert start and end from string to dates (in the right format)
			foreach var of varlist start end {
				rename `var' `var'_temp
				gen `var' = date(`var'_temp, "DMY")
				drop `var'_temp
				format `var' %td
			}

			* Checking if start/end falls inside relevant quarter
			local s = mdy(`q_m_start',`q_d_start', `q_yr')
			local e = mdy(`q_m_end',`q_d_end', `q_yr')
			
			*assert start >= `s' & end <=`e'
			assert start >= `s' & end <=`e' & start <= `e' & end >= `s'
			assert start <= end
		}
	}
}


******************************************************************************
* 3. Merge all HR data
******************************************************************************

clear all

* Compile all HR data and reshape
forval y = 2014/2015 {
	forval q = 1/4 {
		if !(`y' == 2015 & `q' == 4) {
		
			* Prepare file for crosswalking
			insheet using "`crosswalk_all'", comma clear
			keep ballot_circle_id q`q'_`y'_circle_id
			drop if mi(ballot_circle_id, q`q'_`y'_circle_id)
			keep if ballot_circle_id == q`q'_`y'_circle_id
			drop ballot_circle_id
			ren q`q'_`y'_circle_id circle_id
			duplicates drop
			tempfile crosswalk
			sa `crosswalk'
		
			* Remove all crosswalked circles
			use `hr_q`q'_`y'', clear
			drop if inspector == 2
			merge 1:1 circle_id using `crosswalk', keep(match) nogen
			duplicates drop
			
			save `hr_q`q'_`y'', replace
		}
	}
}

clear all
tempfile hr_all
sa `hr_all', emptyok

* Compile all HR data and reshape
forval y = 2014/2015 {
	forval q = 1/4 {
		if !(`y' == 2015 & `q' == 4) {
		
			append using `hr_q`q'_`y''
		}
	}
}

reshape long hr_id start end, i(circle_id qtr fyear inspector) j(j)
drop ins
drop if hr_id == .

* Enter actual start and end dates (instead of blanks)
forval y = 2014/2015 {
	forval q = 1/4 {
		if !(`y' == 2015 & `q' == 4) {
			local q_d_start:	word `q' of `q_day_start'
			local q_d_end: 		word `q' of `q_day_end'
			local q_m_start:	word `q' of `q_month_start'
			local q_m_end:		word `q' of `q_month_end'
			local q_yr:			word `q' of `q_year`y''

			replace start = "`q_d_start'.`q_m_start'.`q_yr'" 	if start == "" 	& qtr == `q' & fyear == `y'
			replace end = 	"`q_d_end'.`q_m_end'.`q_yr'" 		if end == "" 	& qtr == `q' & fyear == `y'
		}
	}
}

* Convert dates from string to date types
foreach var of varlist start end {
	rename `var' `var'_temp
	gen `var' = date(`var'_temp, "DMY")
	drop `var'_temp
	format `var' %td
}


* Find final circle at end of Y2 Q3
preserve
	keep if end == date("31.3.2015", "DMY")
	keep circle_id hr_id
	
	tempfile end_y2q3_circle_hr
	sa `end_y2q3_circle_hr'
restore


* Calculate # of days in circle
gen days_in_circle = end - start

* Add a day to if the inspector started on day 1 of the quarter
forval y = 2014/2015 {
	forval q = 1/4 {
		if !(`y' == 2015 & `q' == 4) {
			local q_d_start:	word `q' of `q_day_start'
			local q_m_start:	word `q' of `q_month_start'
			local q_yr:			word `q' of `q_year`y''

			replace days_in_circle = days_in_circle + 1 if start == date("`q_d_start'.`q_m_start'.`q_yr'", "DMY")			
		}
	}
}

* Compute time spent in circle as fraction of time in quarter
gen fraction_in_circle = .
forval y = 2014/2015 {
	forval q = 1/4 {
		if !(`y' == 2015 & `q' == 4) {
			local total_days_in_qtr : word `q' of `days_in_qtr' // Gets the number of days for the corresponding quarter
			replace fraction_in_circle = days_in_circle / `total_days_in_qtr' if qtr == `q'& fyear == `y'
		}
	}
}

* Calculate total time in circle(s), in case ins was in two circles in one qtr
bys hr_id circle_id qtr fyear: egen time_in_circles = total(fraction_in_circle)

assert time_in_circles <= 1


* Keep only observations where the 'end' date matches with the end of the quarter
forval y = 2014/2015 {
	forval q = 1/4 {
		if !(`y' == 2015 & `q' == 4) {
			local q_d_end:		word `q' of `q_day_end'
			local q_m_end:		word `q' of `q_month_end'
			local q_yr:			word `q' of `q_year`y''

			drop if end != date("`q_d_end'.`q_m_end'.`q_yr'", "DMY") & qtr == `q' & fyear == `y'
		}
	}
}

keep hr_id circle_id fyear qtr time_in_circles days_in_circle
duplicates drop

gen j = qtr if fyear == 2014
replace j = qtr + 4 if fyear == 2015

reshape wide time_in_circles days_in_circle qtr fyear, i(hr_id circle_id) j(j)
merge 1:1 circle_id hr_id using `end_y2q3_circle_hr', assert(1 3) keep(match) nogen


******************************************************************************
* 4. Calculate the number of days in the circle as of Y2 Q3
******************************************************************************

gen still_in_circle = 1
gen days_sum = 0

* Loop backwards through time
forval i = 7(-1)1 {
	replace days_sum = days_sum + days_in_circle`i' if still_in_circle == 1 & !mi(days_in_circle`i')
	replace still_in_circle = 0 if time_in_circles`i' < 1 | mi(time_in_circles`i')
}

ren days_sum time_in_circle
gen any_move = !still_in_circle
keep circle_id hr_id time_in_circle any_move
isid circle_id

label var time_in_circle "Time in Circle (Days), capped at 2 years"
label var time_in_circle "Any Move in Last 2 years"

sa "`output_file'", replace
