clear all
version 13
cap cd "$PAKTAX2_RANDOMIZATION"

********************************************************************************

*1. Create sample
use "Output/Year 1/Year 1 Treated Groups Ballot.dta", clear
count
assert `r(N)' == 153 // 153 circles
assert !missing(treatment) // all treated
assert !missing(ranking_method) // ranking method 
isid circle_id // circle-level data

/*generate group number variable so each group has a unique number across partitions*/ 
sort partition_id group 
egen assigned_group = group(partition_id group)

/*create updated treatment variable*/ 
drop treatment
g treatment = . 
label var treatment "treatment status for year 2 ballot" 

/*create treatment details variable*/
g details_treatment = "dynamic incentives in year 1" 
label var details_treatment "details about treatment status" 

/*create numeric ranking variable*/ // demand == 1, recovery == 2 
g ranking_method_num = 1 if ranking_method == "DEMAND"
replace ranking_method_num = 2 if ranking_method == "RECOVERY" 
label define rank 1 "DEMAND" 2 "RECOVERY"
label values ranking_method_num rank 

/*sort*/ 
sort partition_id ranking_method assigned_group circle_id

********************************************************************************
*2. Allocate groups into Year 2 treatment/control 

**Select seed for ballot 
noisily display "Enter the number chosen by ballot: " _request(SEEDINPUT)
display "$SEEDINPUT"
set seed $SEEDINPUT
set sortseed $SEEDINPUT

*************Lahore (partition_id == 5) **********************

/*loop through demand/recovery groups and randomly select 1 each for treatment*/
forvalues i = 1/2{
	local ranking_method : word `i' of "DEMAND" "RECOVERY"

	**randomly order demand/recovery groups 
	#delimit ; 
	sort partition_id ranking_method assigned_group circle_id ; 
	
	by partition_id ranking_method assigned_group: g rand_lahore`i' = runiform() if _n == 1 
		& inlist(partition_id, 5) & ranking_method == "`ranking_method'" ; 

	egen rank_lahore`i' = rank(rand_lahore`i'), unique ; // rank recovery groups in  lahore
	
	by partition_id ranking_method assigned_group: egen temp = max(rank_lahore`i') ; 
	replace rank_lahore`i' = temp ; 
	drop temp ;
	#delimit cr 

	**assign first demand/recovery group to treatment
	replace treatment = 1 if rank_lahore`i' == 1 
} 

/*confirm we have selected 1 demand & 1 recovery*/ 
summ ranking_method_num if treatment == 1, d
assert `r(min)' == 1 // 1 demand group selected
assert `r(max)' == 2 // 1 recovery group selected

************** Remaining Divisions *******************************

/*randomly order all divisions except Lahore and Sarghoda*/ 
sort partition_id ranking_method assigned_group circle_id
by partition_id: g rand_div = runiform() if _n == 1 & !inlist(partition_id, 5, 10)
egen rank_div = rank(rand_div), unique // rank remaining divisions
by partition_id: egen temp = max(rank_div)
replace rank_div = temp
drop temp

/*randomly pick first group in first division*/ 
sort partition_id ranking_method assigned_group circle_id
by partition_id ranking_method: g rand_group = runiform() if _n == 1 & rank_div == 1 
egen rank_group = rank(rand_group), unique // rank recovery/demand groups within first division
by partition_id ranking_method: egen temp = max(rank_group)
replace rank_group = temp
drop temp

/*assign first group in first division to treatment*/
replace treatment = 1 if rank_div == 1 & rank_group == 1 

/*determine whether this group is demand or recovery*/  
summ ranking_method_num if rank_div == 1 & rank_group == 1
local group_type = `r(mean)' // 1 == demand, 2 == recovery 

/*now, go through the next three divisions,
alternating between recovery, demand selection:*/
replace treatment = 1 if inlist(rank_div, 2, 4) & ranking_method_num != `group_type'
replace treatment = 1 if inlist(rank_div, 3) & ranking_method_num == `group_type'

************** Sarghoda (partition_id == 10)  & Last Division*********************

/*determine whether Sarghoda will be in treatment*/  
sort partition_id ranking_method assigned_group circle_id
g rand_sgd = runiform() if _n <= 2 // generate two random numbers 
egen rank_sgd = rank(rand_sgd), unique // rank these numbers

/*if number in _n == 1 is ranked first, then Sarghoda's recovery group is selected
and last division's demand group is selected*/  
summ rank_sgd if _n == 1
local rank_sgd `r(mean)' 

if `rank_sgd' == 1{
	replace treatment = 1 if partition_id == 10 & ranking_method_num == 2 // Sarghoda recovery group
	replace treatment = 1 if rank_div == 5 & ranking_method_num == 1 // Last division demand group
}

/*otherwise go to the last division and select its recovery group*/
if `rank_sgd' == 2{
	replace treatment = 1 if rank_div == 5 & ranking_method_num == 2 // Last division recovery group
}

/*finally, assign remaining groups to control*/ 
replace treatment = 0 if missing(treatment) 

/*update treatment details variable*/
replace details_treatment = "dynamic incentives in year 1 & year 2" if treatment == 1 

********************************************************************************
*3. Save files and display 

/*save files*/ 
save "Output/Year 2/140805 Treated Groups Year 2 Randomization $SEEDINPUT", replace
