/*

Prepares input for MATLAB simulations

Date created:
	Nov 22, 2017

Summary:
	- 	Prepares output used in MATLAB simulations
	
Notes:

	- 	We use an old version of "Cleaned baseline preferences for simulation" dataset:
		In this dataset, inspectors without preferences (~26/400) were given a randomly
		generated ranking for each circle in their group. In the do file, the seed was set
		but not the sortseed.
	
*/

******************************************************************************
* 0. Initial setup
******************************************************************************

clear all
set more off
cap cd "${PAKTAX2_ANALYSIS}"

* Declare constants here
local num_circles_with_inspectors = 	408

* Declare input file paths
local base_simulation_prefs = 		"TP Analysis/Coded Data/Cleaned baseline preferences for simulation OLD.dta" // Note that this file has missing ranks randomly generated
local base_performance_old = 			"TP Analysis/Coded Data/base_growth_predictions_old"
local base_performance_new = 			"TP Analysis/Coded Data/base_growth_predictions_new"
local hr_q1_2015_file = 			"Data/Raw Data/Current HR Confirmation/140915 HR Verification FY2015 Q1 - Ballot/150109 HR Verification Q1.csv"
local excluded_hr_file = 			"TP Implementation/Data/Excluded HR/151005 Reasons for Dropping from Y2 Ballot.xlsx"
local y2_analysis_file = 			"TP Analysis/Coded Data/TP Y2 Analysis Data"

* Declare output file paths
local output_for_matlab_old = 			"TP Analysis/output/Transfer simulations/output_for_matlab_old.csv"
local base_growth_predictions_old = 	"TP Analysis/output/Transfer simulations/base_growth_predictions_old"
local output_for_matlab_new = 			"TP Analysis/output/Transfer simulations/output_for_matlab.csv"
local base_growth_predictions_new = 	"TP Analysis/output/Transfer simulations/base_growth_predictions_new"

******************************************************************************
* 1. Dataset prep: preferences
******************************************************************************

* Get wide preferences
use "`base_simulation_prefs'", clear // Note that all rankings are already normalized
isid partition_name group hr_id ranking
ren circle_id preference
keep partition_name group hr_id preference ranking norm_ranking
reshape wide preference norm_ranking, i(partition_name group hr_id) j(ranking)
tempfile preferences_wide
save `preferences_wide'

* Get rank of own circle
use "`base_simulation_prefs'", clear 
keep if own_circle == 1
keep partition_name group hr_id circle_id norm_ranking
ren (circle_id norm_ranking) (own_circle_id own_circle_ranking)
bys partition_name group hr_id: gen j = _n
assert j <= 2
reshape wide own_circle_id own_circle_ranking, i(partition_name group hr_id) j(j) // Required because some inspectors have two circles within 1 group
gen best_own_circle_rank = min(own_circle_ranking1, own_circle_ranking2)
gen worst_own_circle_rank = max(own_circle_ranking1, own_circle_ranking2)
drop own_circle_ranking*
tempfile own_circle_ranks
sa `own_circle_ranks'

* Merge together
use `preferences_wide', clear
merge 1:1 partition_name group hr_id using `own_circle_ranks', assert(match) nogen
ren own_circle_id* y1_circle_id*
tempfile preferences
sa `preferences'

******************************************************************************
* 2. Get list of inspectors who were present for Y2 ballot
******************************************************************************

use "`y2_analysis_file'", clear
keep circle_id hr_id partition_id group
duplicates drop
drop if mi(hr_id)
decode partition_id, gen(partition_name)
drop partition_id
bys partition_name group hr_id: gen j = _n
ren circle_id y2_circle_id
reshape wide y2_circle_id, i(partition_name group hr_id) j(j)
tempfile y2_ballot_hr
save `y2_ballot_hr'

******************************************************************************
* 3. Add base performance data
******************************************************************************

use `preferences', clear

* For inspectors with 2 circle in the same group, remove the circle that the inspector was not rated on
reshape long y1_circle_id, i(partition_name group hr_id) j(j)
drop if hr_id == 11661 & y1_circle_id == 108300
drop if hr_id == 40912 & y1_circle_id == 404100
drop if hr_id == 112542 & y1_circle_id == 1101300
drop if hr_id == 112702 & y1_circle_id == 1106400
drop if hr_id == 112546 & y1_circle_id == 1101600
drop if hr_id == 11511 & y1_circle_id == 101300
drop if hr_id == 11671 & y1_circle_id == 109000
drop if hr_id == 40838 & y1_circle_id == 400400
drop if hr_id == 81201 & y1_circle_id == 808800
drop if hr_id == 81006 & y1_circle_id == 802400
drop j
drop if mi(y1_circle_id)

* Add Y2 Ballot Circles
merge 1:1 partition_name group hr_id using `y2_ballot_hr', keep(1 3)
gen y1_only = (_m != 3)
drop _m
assert mi(y2_circle_id3, y2_circle_id4)
drop y2_circle_id3 y2_circle_id4
gen y2_circle_id = y2_circle_id1

* Dump circles that inspectors were not rated on
replace y2_circle_id = 108101 if hr_id == 11673 & partition_name == "BAHAWALPUR" & group == 1
replace y2_circle_id = 101200 if hr_id == 11511 & partition_name == "BAHAWALPUR" & group == 3
replace y2_circle_id = 107200 if hr_id == 11652 & partition_name == "BAHAWALPUR" & group == 3
replace y2_circle_id = 501101 if hr_id == 51000 & partition_name == "LAHORE" & group == 3
replace y2_circle_id = 800521 if hr_id == 81006 & partition_name == "MULTAN" & group == 6
replace y2_circle_id = 905300 if hr_id == 92303 & partition_name == "RAWALPINDI" & group == 2
assert inlist(y2_circle_id, y2_circle_id1, y2_circle_id2)
drop y2_circle_id?

tempfile data
save `data'

forvalues j=1/2 {
local version: word `j' of "old" "new"

use `data', clear

* Add base performance for Y1 balloted circles
ren y1_circle_id circle_id
merge 1:1 circle_id using "`base_performance_`version''", assert(2 3) keep(match) keepusing(y1_performance_prediction y1_performance_t ) nogen
ren circle_id y1_circle_id

* Add base performance for Y2 balloted circles
ren y2_circle_id circle_id
merge m:1 circle_id using "`base_performance_`version''", keep(1 3) keepusing(y2_performance_prediction) nogen
ren circle_id y2_circle_id

* Store base growth predictions
preserve
	keep partition_name group hr_id y1_circle_id y2_circle_id y1_performance_prediction y2_performance y1_only
	sa "`base_growth_predictions_`version''", replace
restore

* Replace missing values with mean base performance of all inspectors of the group

	summ y2_performance_prediction, meanonly
	local y2_mean = `r(mean)'
	replace y2_performance_prediction = `y2_mean' if mi(y2_performance_prediction)

	bys partition_name group: egen mean_pred=mean(y1_performance_prediction)
	replace y1_performance_prediction = mean_pred if mi(y1_performance_prediction)

* Save output
sort partition_name group hr_id
egen group_id = group(partition_name group)
drop *circle_id group 
order group_id hr_id preference* norm* best_own_circle_rank worst_own_circle_rank
drop partition_name
outsheet using "`output_for_matlab_`version''", comma replace

}

