function avg_effort = return_average_effort(filename, full_knowledge, input_file, alpha, base_performance, prefs_file)
    
    rng('default'); % Set seed to default
    
    % input data file
    data = csv2mat_numeric2(input_file);

    % Declare constants here
    max_circles_in_group = 11;
    num_inspectors = length(data.hr_id);
    num_groups = max(data.group_id);
    outcome_stdev = .18235865; % Computed using Stata
    
    % Load base_performance values
    if base_performance == 0 % Base performance is zero growth
        y0_mean = zeros(num_inspectors, 1);
    elseif base_performance == 1 % Use Y1 predictions
        y0_mean = data.y1_performance_prediction;
    end
    
    % (398x1): HR IDs and group IDs.
    group_id = data.group_id;
    hr_id = data.hr_id;
    
    % (398x11): Each row is the preference ordering for a given inspector.
    preferences = [data.preference1, data.preference2, data.preference3, data.preference4, data.preference5, data.preference6, data.preference7, data.preference8, data.preference9, data.preference10, data.preference11];
        
    % Calculate the number of inspectors in each group
    [counts,indices] = histc(group_id, unique(group_id));
    group_ins_count = counts(indices);
    
    % Calculate u1 (Linear scale of 1 to 0)
    
    % creates a 398*11 matrix
    indices_repeated = repmat(1:max_circles_in_group, num_inspectors, 1);
    group_ins_count_repeated = repmat(group_ins_count, 1, max_circles_in_group);
    
    % e.g. if 10 people in group, each element is
    % 1 - 0/(10-1), 1 - 1/(10-1), and so on...
    u1 = 1 - ( (indices_repeated - 1) .* (1./(group_ins_count_repeated - 1)) );
    u1(u1 < 0) = NaN;
    
    % see line 203
    % input list of 1st pref of 1st rank, 1st + 2nd pref of 2nd rank
    % created assuming person in each rank has random preferences
    if full_knowledge==2
        prefs_list = csvread(prefs_file);
    end
    
% For each iteration, find optimal effort response, until convergence
    
    % Setting a maximum no. of iterations for effort updates
    if full_knowledge==1 
        maxiter = 100;
    end
    
    if full_knowledge==2
        maxiter = 100;
    end
        
    if full_knowledge==0
        maxiter = 200;
    end
    
    % no. of noise draws (for each effort level)
    
    % if full knowledge or identical prefs
    if full_knowledge==1 || full_knowledge==0
        num_noise_iter = 200;
    end
    
    % if random prefs
    if full_knowledge==2
        num_noise_iter = 1000;
    end
    
    % creating 11x121 matrix 
    % = 1 in columns 1-11 in row 1
    % = 1 in columns 12-22 in row 2, and so on
    rep_mat_ones=zeros(11, 121);
    for g = 1:11
        rep_mat_ones(g,(g-1)*11 + 1:11*g)=1;
    end
    
    tic;
       
    % store for all noise draws per effort_vector update    
    dE_u1_all = zeros(num_inspectors, num_noise_iter);
    
    % Store each effort vector
    xArray = NaN(num_inspectors,maxiter);
    
    zero_mat=zeros(num_inspectors,1);
    
    % ln of effort + 1
    if full_knowledge==0
        mean_ln_effort=zero_mat + 0.60045586;
        stddev_ln_effort=0.207993168;
    end
    
    if full_knowledge==1
        mean_ln_effort=zero_mat + 0.412026015;
        stddev_ln_effort=0.216476441;
    end
    
    if full_knowledge==2
        mean_ln_effort=zero_mat + 0.474198505;
        stddev_ln_effort=0.063732923;
    end
    
    effort_vector_ln=normrnd(mean_ln_effort, stddev_ln_effort);  
    effort_vector=max(exp(effort_vector_ln)-1,0);
    
    iter=0;

 % no. of iterations in which effort updates
    while (iter < maxiter)
        
        iter = iter + 1;
        xArray(:,iter) = effort_vector;
        y_no_noise = y0_mean + effort_vector;
        
        % for each effort level draw 200 different noise iterations (2000
        % if random prefs)
        
        for it = 1:num_noise_iter
            
          % First, calculate dpr/de of being in different ranks
           
          % drawing realization of ys
            y_i = normrnd(y_no_noise,outcome_stdev);
          
          % sorting in descending order of y_is
            z=[group_id, y_i, y_no_noise, preferences, effort_vector, u1];    
            
            [z_sorted, sort_id]=sortrows(z, [1,-2]);
            
          % creating rank matrix (398x1) with rank within groups 
            j=z_sorted(:,2); 
            rank = group_id;
            a = unique(group_id);
            for ii = 1:numel(a)
                t = group_id == a(ii);
                [~,rank(t)] = sort(j(t), 'descend');
            end
            
            % for each group, create cell with y_is in that group, and index by
            % group_id
          
            y_i_gp = accumarray(z_sorted(:,1),z_sorted(:,2),[],@(n){n});
            
            % Convert y_i_gp into matrix (convert last entries to nan if
            % <11 inspectors)
            
            y_i_gp_mat=padcat(cell2mat(y_i_gp(1,:)), cell2mat(y_i_gp(2,:)), cell2mat(y_i_gp(3,:)), cell2mat(y_i_gp(4,:)), cell2mat(y_i_gp(5,:)), cell2mat(y_i_gp(6,:)), cell2mat(y_i_gp(7,:)), cell2mat(y_i_gp(8,:)), cell2mat(y_i_gp(9,:)), cell2mat(y_i_gp(10,:)), cell2mat(y_i_gp(11,:)), cell2mat(y_i_gp(12,:)), cell2mat(y_i_gp(13,:)), cell2mat(y_i_gp(14,:)), cell2mat(y_i_gp(15,:)), cell2mat(y_i_gp(16,:)), cell2mat(y_i_gp(17,:)), cell2mat(y_i_gp(18,:)), cell2mat(y_i_gp(19,:)), cell2mat(y_i_gp(20,:)), cell2mat(y_i_gp(21,:)), cell2mat(y_i_gp(22,:)), cell2mat(y_i_gp(23,:)), cell2mat(y_i_gp(24,:)), cell2mat(y_i_gp(25,:)), cell2mat(y_i_gp(26,:)), cell2mat(y_i_gp(27,:)), cell2mat(y_i_gp(28,:)), cell2mat(y_i_gp(29,:)), cell2mat(y_i_gp(30,:)), cell2mat(y_i_gp(31,:)), cell2mat(y_i_gp(32,:)), cell2mat(y_i_gp(33,:)), cell2mat(y_i_gp(34,:)), cell2mat(y_i_gp(35,:)), cell2mat(y_i_gp(36,:)), cell2mat(y_i_gp(37,:)), cell2mat(y_i_gp(38,:)), cell2mat(y_i_gp(39,:)), cell2mat(y_i_gp(40,:)), cell2mat(y_i_gp(41,:)))';

            % Create matrix y_i_g, where each row corresponds to an inspector,
            % and columns 1-11 represent y_is, in descending order, of all
            % inspectors in the row inspector's group (note: this includes
            % the inspector themselves, for now)
                
            y_i_g = y_i_gp_mat(z_sorted(:,1),:);
           
            % Remove inspector's own y_i from list
            
            y_out=y_i_g';
            
            y_out = reshape(y_out(bsxfun(@ne, y_out, z_sorted(:, 2)')), [10,num_inspectors]);
            
            y_i_g=y_out';
            
            % create first entry = inf, last entry = -inf
            
            y_i_g = [Inf(num_inspectors,1), y_i_g, -Inf(num_inspectors,1)];
            
            % shift -Inf to be the last non-empty entry in row (<11 inspectors in group)

            [row, col]=find(isnan(y_i_g));
            index_nans = sub2ind(size(y_i_g), row, col);
            
            % convert all nans to -inf
            y_i_g(index_nans)=-Inf;
            
            % convert excess -Inf to nans
            y_i_g(index_nans+num_inspectors)=nan;
          
            % calculate pdf
         
            dPhi_1 = normpdf(bsxfun(@minus, y_i_g(:,1:max_circles_in_group), z_sorted(:,3)), 0, outcome_stdev);
            dPhi_2 = normpdf(bsxfun(@minus, y_i_g(:,2:max_circles_in_group+1), z_sorted(:,3)), 0, outcome_stdev);
            dPr_rank = -dPhi_1 + dPhi_2;
     
    % Find utility from being in each rank
           
           % If identical preferences: 
            if full_knowledge==0
                pref_received=[1,2,3,4,5,6,7,8,9,10,11];
                pref_received=repmat(pref_received, num_inspectors, 1);
            end
           
           % If full knowledge of preferences:
           
           % Step 1: Generate row containing 1st pref of rank 1, 1st 2
           % prefs of rank 2 etc. (ranks other than inspector themselves)
           
           prefs_real=z_sorted(:,4:14);
           
           if full_knowledge==1 
               rel_prefs=gen_prefs_mat(prefs_real, group_id, rank, rep_mat_ones);
           end
           
           % If random preferences:
           
           % Step 1: Already generated (assuming random preferences) rows 
           % containing 1st pref of rank 1, 1st 2 prefs of rank 2 etc. 
           % pick one from 5000
           
           if full_knowledge==2
               
                % generate random number between 1-5000 for each person
                r = randi([1 5000],num_inspectors,1);
                rows=group_id+(r-1)*41;
                
                % pick all others' preferences from already generated
                % prefs_list
                
                rel_prefs=prefs_list(rows,:);
           end
           
           % Step 2: Run 11 rounds of transfers to find preference received from being in each rank
           
            if full_knowledge==1 || full_knowledge==2
                pref_received=find_prefs(rel_prefs, prefs_real);
            end
            
            % convert to 11 at end of row with <11 group members (0
            % utility added)
            
            pref_received(index_nans)=11;

            % Assign utility value received
            
            u=z_sorted(:,16:26)';
            
            pref_received=pref_received';
            
            % from each rank: pick corresponding u for that inspector
            u1_pref_rank=nan(max_circles_in_group, num_inspectors);
            for h=1:11
                u1_pref_rank(h,:) = u(sub2ind(size(u),pref_received(h,:),1:numel(pref_received(h,:)))); 
            end
            
            % convert back to 398x11 matrix
            u1_pref_rank=u1_pref_rank';

            % Compute derivative of expected utility
            dPr_rank(isnan(dPr_rank))=0;
            u1_pref_rank(isnan(u1_pref_rank))=0;
            dE_u1 = sum(dPr_rank .* u1_pref_rank,2);
            dE_u1(sort_id)=dE_u1;
                
            % storing for noise iteration
            dE_u1_all(:,it) = dE_u1;
                
        end
        
        % average each row across all noise iterations (one row = one insp)
        
        dE_u1_avg = mean(dE_u1_all,2);
        
        % updater
        updater=dE_u1_avg/(2*alpha);
        
        % effort_vector update (note: we update regardless of error; then
        % we observe if converge to fp over last 15 or so iterations)
        
        effort_vector= (0.8 .* effort_vector) + (0.2.* updater);
        effort_vector(effort_vector<0)=0;
        
    end 
    
    %dlmwrite(strcat(filename, '.csv'), [xArray], 'precision', '%i');
    avg_effort=mean(effort_vector);
    delete(gcp('nocreate'));