function run_simulation(base_performance_type, full_knowledge, num_iter, filename, input_file)
    %{
    Args:
        base_performance_type:
            0 if base performance is zero
            1 if base performance is Y1 predicted values
            2 if base performance is Y2 predicted values

        full_knowledge: 
            0 if inspector assumes everyone shares his preferences
            1 if inspector has full knowledge of everyone's preferences
            2 if inspector assumes others' preferences are random

        num_iter: 
            Number of iterations that simulation will run

        filename:
            Name of file to save results to (do not specity num iterations)

        input_file:
            Location of input file
    %}
    rng('default'); % Set seed to default

    data = csv2mat_numeric(input_file);

    % Declare constants here
    max_circles_in_group = 11;
    num_inspectors = length(data.hr_id);
    num_groups = max(data.group_id);
    outcome_stdev = .18235865; % Computed using Stata
    
    % Load base_performance values
    if base_performance_type == 0 % Base performance is zero growth
        outcome_mean = zeros(num_inspectors, 1);
    elseif base_performance_type == 1 % Use Y1 predictions
        outcome_mean = data.y1_performance_prediction;
    elseif base_performance_type == 2 % Use Y2 predictions
        outcome_mean = data.y2_performance_prediction;
    else
        exit
    end

    % (398x1): HR IDs and group IDs.
    group_id = data.group_id;
    hr_id = data.hr_id;
    
    % (398x11): Each row is the preference ordering for a given inspector.
    preferences = [data.preference1, data.preference2, data.preference3, data.preference4, data.preference5, data.preference6, data.preference7, data.preference8, data.preference9, data.preference10, data.preference11];
    
    % (398x11): Normalized preference rankings from 1 to 10 for each
    %           inspector. Each row represents 1 inspector
    rankings = [data.norm_ranking1, data.norm_ranking2, data.norm_ranking3, data.norm_ranking4, data.norm_ranking5, data.norm_ranking6, data.norm_ranking7, data.norm_ranking8, data.norm_ranking9, data.norm_ranking10, data.norm_ranking11];
    
    % (398x1):  Records the rank of the inspector's current circle (if in 2
    %           circles, then records the "best" or "worst" rank)
    best_own_circle_rank = data.best_own_circle_rank;
    worst_own_circle_rank = data.worst_own_circle_rank;
    
    % (398x1): 1 if inspector was balloted in Y1 only, 0 otherwise
    y1_only = data.y1_only;
        
    % Remove inspectors that were not included in Y2 ballot if using Y2
    % predictions
    if base_performance_type == 2
        group_id = group_id(y1_only == 0);
        hr_id = hr_id(y1_only == 0);
        preferences = preferences(y1_only == 0, :);
        rankings = rankings(y1_only == 0, :);
        best_own_circle_rank = best_own_circle_rank(y1_only == 0);
        worst_own_circle_rank = worst_own_circle_rank(y1_only == 0);
        num_inspectors = length(hr_id);
    end
    
    % Calculate the number of inspectors in each group
    [counts,indices] = histc(group_id, unique(group_id));
    group_ins_count = counts(indices);
    
    % Calculate u1 (Linear scale of 1 to 0)
    indices_repeated = repmat(1:max_circles_in_group, num_inspectors, 1);
    group_ins_count_repeated = repmat(group_ins_count, 1, max_circles_in_group);
    u1 = 1 - ( (indices_repeated - 1) .* (1./(group_ins_count_repeated - 1)) );
    u1(u1 < 0) = NaN;
        
    % Calculate u2 (1 for best circle, 0 otherwise)
    u2 = zeros(size(u1));
    u2(:,1) = 1;
    
    % Calculate u3 (1 for better than "best" current circle, 0 otherwise)
    best_rank = repmat(best_own_circle_rank, 1, max_circles_in_group);
    u3 = rankings <= best_rank;
    
    % Calculate u4 (1 for worse than "worst" current circle, 0 otherwise)
    %       i.e.: Inspector is "forced out"
    worst_rank = repmat(worst_own_circle_rank, 1, max_circles_in_group);
    u4 = rankings > worst_rank;
    
    % Calculate u5 (1 for current circle(s), 0 otherwise)
    %       i.e.: Inspector is moved out of current circle
    u5 = (rankings == worst_rank) | (rankings == best_rank);

    % Calculate u6 (1 for better than "best" current circle, 0 otherwise)
    u6 = rankings < best_rank;
    
    % (num_iter x 398): temporary variables for return to effort
    dE_u1 = zeros(num_iter, num_inspectors);
    dE_u2 = zeros(num_iter, num_inspectors);
    dE_u3 = zeros(num_iter, num_inspectors);

    % (num_iter x 398): temporary variables for expected utility
    E_u4 = zeros(num_iter, num_inspectors);
    E_u5 = zeros(num_iter, num_inspectors);
    E_u6 = zeros(num_iter, num_inspectors);
    
    tic
    
    % For each iteration 
    for iter = 1:num_iter
        
        % Simulate performance. Dim: (398x1)
        y_0 = normrnd(outcome_mean, outcome_stdev);

        curr_ins = 1;

        % For each group
        for g = 1:num_groups

            % Rank inspectors by simulated performance, and keep only
            % inspectors for the current group.
            [y_0_g, sort_id] = sort(y_0(group_id == g), 'descend');
            num_ins = length(y_0_g); % Num of inspectors

            % Create matrix of "base" performance
            outcome_mean_g = outcome_mean(group_id == g);
            outcome_mean_g = repmat(outcome_mean_g(sort_id)', num_ins, 1);

            % Get preferences for group
            preferences_g = preferences(group_id == g, :);
            preferences_g = preferences_g(sort_id, 1:num_ins);

            % Save y_0_g in easier format for computing probabilities
            y_0_g = repmat(y_0_g, 1, num_ins);
            y_0_g = [Inf(1, num_ins); reshape(y_0_g(eye(size(y_0_g)) ~= 1), num_ins-1, num_ins); -Inf(1, num_ins)];

            % Compute dPr(inspector i (column) achieves rank k (row) )
            dPhi_1 = normpdf(y_0_g(1:num_ins, :) - outcome_mean_g, 0, outcome_stdev);
            dPhi_2 = normpdf(y_0_g(2:num_ins+1, :) - outcome_mean_g, 0, outcome_stdev);
            dPr_rank = -dPhi_1 + dPhi_2;
            
            % Compute Pr(inspector i (column) achieves rank k (row) )
            Phi_1 = normcdf(y_0_g(1:num_ins, :) - outcome_mean_g, 0, outcome_stdev);
            Phi_2 = normcdf(y_0_g(2:num_ins+1, :) - outcome_mean_g, 0, outcome_stdev);
            Pr_rank = Phi_1 - Phi_2;

            % Simulate transfers for each inspector.
            % pref_rank refers to the rank of the inspector's outcome for each
            % possible performance ranking
            pref_ranks = zeros(num_ins, num_ins);
            for ins = 1:num_ins % For each inspector
                pref_ranks(:, ins) = find_pref_ranks(ins, preferences_g, full_knowledge);
            end

            % Get utility values for the group
            u1_g = u1(group_id == g, :);
            u1_g = u1_g(sort_id, 1:num_ins)';
            u2_g = u2(group_id == g, :);
            u2_g = u2_g(sort_id, 1:num_ins)';
            u3_g = u3(group_id == g, :);
            u3_g = u3_g(sort_id, 1:num_ins)';
            u4_g = u4(group_id == g, :);
            u4_g = u4_g(sort_id, 1:num_ins)';
            u5_g = u5(group_id == g, :);
            u5_g = u5_g(sort_id, 1:num_ins)';
            u6_g = u6(group_id == g, :);
            u6_g = u6_g(sort_id, 1:num_ins)';

            % Assign utility value to each preference rank
            u1_pref_rank = u1_g(pref_ranks);
            u2_pref_rank = u2_g(pref_ranks);
            u3_pref_rank = u3_g(pref_ranks);
            u4_pref_rank = u4_g(pref_ranks);
            u5_pref_rank = u5_g(pref_ranks);
            u6_pref_rank = u6_g(pref_ranks);

            % Compute derivative of expected utility
            dE_u1_g = sum(dPr_rank .* u1_pref_rank, 1);
            dE_u2_g = sum(dPr_rank .* u2_pref_rank, 1);
            dE_u3_g = sum(dPr_rank .* u3_pref_rank, 1);
            dE_u1_g(sort_id') = dE_u1_g;
            dE_u2_g(sort_id') = dE_u2_g;
            dE_u3_g(sort_id') = dE_u3_g;
            
            % Compute expected utility
            E_u4_g = sum(Pr_rank .* u4_pref_rank, 1);
            E_u5_g = sum(Pr_rank .* u5_pref_rank, 1);
            E_u6_g = sum(Pr_rank .* u6_pref_rank, 1);
            E_u4_g(sort_id') = E_u4_g;
            E_u5_g(sort_id') = E_u5_g;
            E_u6_g(sort_id') = E_u6_g;

            % Add dE_u values to "master" data structures
            dE_u1(iter, curr_ins:(curr_ins+num_ins-1)) = dE_u1_g;
            dE_u2(iter, curr_ins:(curr_ins+num_ins-1)) = dE_u2_g;
            dE_u3(iter, curr_ins:(curr_ins+num_ins-1)) = dE_u3_g;
            
            % Add E_u values to "master" data structures
            E_u4(iter, curr_ins:(curr_ins+num_ins-1)) = E_u4_g;
            E_u5(iter, curr_ins:(curr_ins+num_ins-1)) = E_u5_g;
            E_u6(iter, curr_ins:(curr_ins+num_ins-1)) = E_u6_g;

            curr_ins = curr_ins + num_ins;
        end
    end
    
    % Display speed stats
    time_elapsed = toc;
    disp(strcat('Total time = ', num2str(time_elapsed), 's'));
    disp(strcat('Number of iterations = ', num2str(num_iter)));
    disp(strcat('Time per 10,000 iterations = ', num2str((time_elapsed / num_iter) * (10000 / 60)), 'min'));

    % Calculate mean of d(expected utility)
    dE_u1_mean = mean(dE_u1, 1)';
    dE_u2_mean = mean(dE_u2, 1)';
    dE_u3_mean = mean(dE_u3, 1)';
    
    % Calculate mean of expected utility
    E_u4_mean = mean(E_u4, 1)';
    E_u5_mean = mean(E_u5, 1)';
    E_u6_mean = mean(E_u6, 1)';

    % Save output
    % In _all files, columns are inspectors, rows are iterations
    % In _mean files, rows are inspectors
    %dlmwrite(strcat(filename, '_Eu1.csv'), dE_u1, 'precision', '%i');
    %dlmwrite(strcat(filename, '_Eu2.csv'), dE_u2, 'precision', '%i');
    %dlmwrite(strcat(filename, '_Eu3.csv'), dE_u3, 'precision', '%i');
    dlmwrite(strcat(filename, '.csv'), [group_id hr_id dE_u1_mean dE_u2_mean dE_u3_mean E_u4_mean E_u5_mean E_u6_mean], 'precision', '%i');
end