/*
Graphs for basic treatment effect in Year 1 / Year 2 / Pooled data 
*/

*************************************************************
* Initial Setup
*************************************************************

clear all
set more off
cap cd "${TP_ANALYSIS}"
do "Do Files/programs/all_programs.do"

************************************************************* 
* Prepare datasets
*************************************************************

* Load Y1 data (to be used as baseline in some regressions)
use "Coded Data/150525 TP Analysis Data FULL SAMPLE", clear
keep circle_id qtr ln_gross_* ln_net_* ln_recov_*
foreach var in recov_tot net_dem gross_dem {
	foreach x in c a t {
		ren ln_`var'_`x' y1_ln_`var'_`x'
	}
}

* Load and temporarily save Y2 data
merge 1:1 circle_id qtr using "Coded Data/TP Y2 Analysis Data w Y1 Treatment", keep(match)
drop if litigated == 1 // drop litigated circles
keep if qtr == 4
drop if treatment_y1 == 1
gen y1 = 0
ren (DEM_sel REV_sel treatment) (DEM_sel_y2 REV_sel_y2 treatment_y2)
label var treatment_y2 "Treatment"
label var DEM_sel_y2 "Demand"
label var REV_sel_y2 "Revenue"
ren treatment_y2 treatment
gen baseline_c = .
gen baseline_a = .
gen baseline_t = .
drop if mi(treatment_y1)
gen ln_recov_tot_t_g=ln_recov_tot_t-base_ln_recov_tot_t
tempfile y2_data
sa `y2_data'

* Load and temporarily save Y1 data
use "Coded Data/150525 TP Analysis Data", clear
drop if litigated == 1
keep if qtr == 4
merge 1:1 circle_id using "Coded Data/Y2 Q1 Demand", assert(2 3) keep(match) keepusing(ln*) nogen
foreach x in t c a {
	foreach d in net_dem gross_dem {
		replace ln_`d'_`x' = ln_y2q1_`d'_`x' // Replace Y1 Q4 Demand values with Y2 Q1 Demand values (because that is when Demand is updated).
	}
}
drop *y2q1*
gen y1 = 1
gen baseline_c = .
gen baseline_a = .
gen baseline_t = .
ren (DEM_sel REV_sel treatment) (DEM_sel_y1 REV_sel_y1 treatment_y1)
label var treatment_y1 "Treatment"
label var DEM_sel_y1 "Demand"
label var REV_sel_y1 "Revenue"
ren treatment_y1 treatment
gen ln_recov_tot_t_g=ln_recov_tot_t-base_ln_recov_tot_t
tempfile y1_data
sa `y1_data'

* Create pooled dataset
use `y1_data', clear
append using `y2_data'
gen base_y1_interact_c = .
gen base_y1_interact_a = .
gen base_y1_interact_t = .
gen pre_c = .
gen pre_a = .
gen pre_t = .
forval i = 1/33 {
	gen stratdum_y1_interact`i' = y1 * stratdum`i'
	replace stratdum`i' = 0 if mi(stratdum`i')
	replace stratdum_y1_interact`i' = 0 if mi(stratdum_y1_interact`i')
}
tempfile pooled_data
sa `pooled_data'

*************************************************************
* Graphs
*************************************************************

forvalues i=1/2 {
local dataset: word `i' of "`y1_data'" "`y2_data'" 
local name: word `i' of "y1" "y2" 
local title: word `i' of "Y1" "Y2" 
 
use `dataset', clear

***************************
* Empirical CDFs
***************************

set scheme s1color

bys treatment: cumul ln_recov_tot_t_g, g(cdf) equal
g cdf1 = cdf if treatment == 1
g cdf0 = cdf if treatment == 0
label var cdf1 "Treatment"
label var cdf0 "Control"
label var ln_recov_tot_t_g "Log of Recovery (`title') - Log of Recovery at baseline"
sort ln_recov_tot_t_g
twoway (line cdf1 ln_recov_tot_t_g, lcolor(maroon)) (line cdf0 ln_recov_tot_t_g, clpattern(dash) lcolor(blue)), xtick(-1(.5)2) xlabel(-1(.5)2) saving(output/Paper/CDF_`name',replace) title("CDF")

***************************
* Empirical PDFs
***************************

kdensity ln_recov_tot_t_g if treatment==1, n(200) g(a1x a1y) ep
kdensity ln_recov_tot_t_g if treatment==0, n(200) g(a0x a0y) ep
label var a1y "Treatment"
label var a0y "Control"
label var a0x "Log of Recovery (`title') - Log of Recovery at baseline"
label var a1x "Log of Recovery (`title') - Log of Recovery at baseline"
twoway (line a1y a1x, lcolor(maroon)) (line a0y a0x, clpattern(dash) lcolor(blue)), xtick(-1(.5)2) xlabel(-1(.5)2) saving(output/Paper/PDF_`name',replace) title("PDF")

graph combine "output/Paper/CDF_`name'.gph" "output/Paper/PDF_`name'.gph", xsize(6) ysize(4) saving("output/Paper/PDFCDF_`name'",replace)
graph export "output/Paper/PDFCDF_`name'.pdf", replace
erase "output/Paper/CDF_`name'.gph" 
erase "output/Paper/PDF_`name'.gph"
erase "output/Paper/PDFCDF_`name'.gph"

}

