/*
Create full interaction table using Y2 Q4 data. Includes RI.

*/

*************************************************************
* Initial Setup
*************************************************************

clear all
set more off
cap cd "${TP_ANALYSIS}"
do "Do Files/programs/all_programs.do"

*************************************************************
* Define a program for storing p values from Rand Inference
*************************************************************

cap prog drop add_pval 
program define add_pval, eclass // Name of the command
syntax,  results(string) pval1(real) pval2(real) pval3(real) indvar1(string) indvar2(string) indvar3(string) // Associate p with estimates of y, local pval and indep variable indvar.

estimates restore `results'

matrix pval=J(1,3,.) // Opens a space for pvalue
matrix colnames pval="`indvar1'" "`indvar2'"  "`indvar3'" 

matrix pval[1,1]=`pval1' // Defines where the value comes from
matrix pval[1,2]=`pval2' 
matrix pval[1,3]=`pval3' 

estadd matrix pval pval // Stores the matrix

end

*************************************************************
* Prepare dataset(s)
*************************************************************

use "Coded Data/150525 TP Analysis Data FULL SAMPLE", clear
keep circle_id qtr ln_gross_* ln_net_* ln_recov_*
foreach var in recov_tot net_dem gross_dem {
	foreach x in c a t {
		ren ln_`var'_`x' y1_ln_`var'_`x'
	}
}
* Load and temporarily save Y2 Q4 data
merge 1:1 circle_id qtr using "Coded Data/TP Y2 Analysis Data w Y1 Treatment", keep(match)
drop if litigated == 1 // drop litigated circles
keep if qtr == 4
drop if mi(treatment_y1)
replace treatment_y1 = 0 if mi(treatment_y1) // Check this with Ben
gen y1_treat_or_y2_treat = treatment_y1 | treatment
replace y1_treat_y2_treat = treatment_y1 & treatment

* Label variables
label var treatment_y1 			"Y1 Treatment"
label var treatment 			"Y2 Treatment"
label var y1_treat_y2_treat 	"Y1 AND Y2 Treatment"
label var y1_treat_or_y2_treat	"Y1 OR Y2 Treatment"

tempfile y2_data
sa `y2_data'

*************************************************************
* Prepare dataset(s) II: Randomization files
*************************************************************

local num 2000

quietly{
forval m = 1/`num' {

* Load and temporarily save Y2 Q4 data
use "Coded Data/TP Y2 Analysis Data w Y1 Treatment", clear
drop if litigated == 1 // drop litigated circles
keep if qtr == 4
drop treatment* DEM_sel* REV_sel* group_id
merge 1:1 circle_id using "Coded Data/RI/rand_code_iter", keepusing(treatment_y1_`m'  treatment_y2_`m' DEM_sel_y1_`m' REV_sel_y1_`m' DEM_sel_y2_`m' REV_sel_y2_`m' group_id_`m') 
drop if mi(treatment_y1_`m')
quietly tab group_id_`m', gen(group_dummy)
rename  treatment_y2_`m' treatment_`m'
replace treatment_y1_`m' = 0 if mi(treatment_y1_`m') // ?? This does nothing
gen y1_treat_or_y2_treat_`m' = treatment_y1_`m' | treatment_`m'
gen y1_treat_y2_treat_`m' = treatment_y1_`m' & treatment_`m'

* Label variables
label var treatment_y1_`m' 			"Y1 Treatment"
label var treatment_`m' 			"Y2 Treatment"
label var y1_treat_y2_treat_`m' 	"Y1 AND Y2 Treatment"
label var y1_treat_or_y2_treat_`m'	"Y1 OR Y2 Treatment"

tempfile y2_data_`m'
sa `y2_data_`m''
}
}

*************************************************************
* Run regressions
*************************************************************

forval z = 1/1 {

	local var : word `z' of recov_tot net_dem gross_dem
	local w1 : word `z' of "Recovery" "Net Demand" "Gross Demand"
	local w2 : word `z' of "recovery" "net demand" "gross demand"
	local file interaction_complete_`var'_simple_rand
	
		foreach x in c a t {
	
		quietly{ // Regressions for randomized treatments
		tempname y2_data_rand_inf_`var'_`x'
		postfile `y2_data_rand_inf_`var'_`x'' b_treatment se_treatment b_treatment_y1 se_treatment_y1 b_y1_treat_y2_treat se_y1_treat_y2_treat using y2_data_rand_inf_`var'_`x'.dta, replace 
		forval m = 1/`num' {
		use `y2_data_`m'', clear
		reg ln_`var'_`x' treatment_`m' treatment_y1  y1_treat_y2_treat_`m'   base_ln_`var'_`x' , cluster(circle_id) // treatment_y1_`m'  y1_treat_y2_treat_`m' 
		post `y2_data_rand_inf_`var'_`x'' (_b[treatment_`m']) (_se[treatment_`m']) (_b[treatment_y1]) (_se[treatment_y1]) (_b[y1_treat_y2_treat_`m']) (_se[y1_treat_y2_treat_`m'])
		}
		postclose `y2_data_rand_inf_`var'_`x''
		}
	
		*Run Y2 regressions until Q4
		use `y2_data', clear
		
		* Indep. variables: Y1 treatment only, Y2 treatment only, Y1 & Y2 treatment
		eststo treat_complete_`x' : reg ln_`var'_`x'  treatment treatment_y1 y1_treat_y2_treat base_ln_`var'_`x', cluster(circle_id)	
		qui test treatment == treatment_y1
		qui sum ln_`var'_`x' if e(sample) == 1 & y1_treat_y2_treat == 0 & treatment == 0 & treatment_y1 == 0
		scalar ymean1 = `r(mean)'		
		estadd scalar ymean1 = `r(mean)'		
		qui sum y1_ln_`var'_`x'  if e(sample) == 1 & y1_treat_y2_treat == 0 & treatment == 0 & treatment_y1 == 0
		scalar ymean0 = `r(mean)'
		estadd scalar ymean0 = `r(mean)'
		scalar ymean=`=ymean1'-`=ymean0'
		estadd scalar ymean=`=ymean1'-`=ymean0'		
		
		scalar b_treatmentb = _b[treatment]
		estadd scalar b_treatmentb = _b[treatment]
		scalar b_treatment_y1b = _b[treatment_y1]
		estadd scalar b_treatment_y1b = _b[treatment_y1]
		scalar b_y1_treat_y2_treatb = _b[y1_treat_y2_treat]
		estadd scalar b_y1_treat_y2_treatb = _b[y1_treat_y2_treat]
		
		scalar difb=`=b_treatmentb'-`=b_treatment_y1b'
		estadd scalar difb=`=b_treatmentb'-`=b_treatment_y1b'

		scalar difb123=`=b_treatment_y1b'+`=b_y1_treat_y2_treatb'-`=b_treatmentb'
		estadd scalar difb123=`=b_treatment_y1b'+`=b_y1_treat_y2_treatb'-`=b_treatmentb'
		scalar difb13=`=b_treatment_y1b'+`=b_y1_treat_y2_treatb'
		estadd scalar difb13=`=b_treatment_y1b'+`=b_y1_treat_y2_treatb'

		eststo treat_complete_`x'
		
		use y2_data_rand_inf_`var'_`x'.dta, clear

		preserve
		keep if abs(b_treatment)> abs(`=b_treatmentb') 
		if _N==0{
			local b_treatmentp= 0.001
			}
		else {
			local b_treatmentp = _N / `num' 
			}
		display `b_treatmentp'
		restore
		
		preserve
		keep if abs(b_treatment_y1)> abs(`=b_treatment_y1b') 
		if _N==0{
			local b_treatment_y1p= 0.001
			}
		else {
			local b_treatment_y1p = _N / `num' 
			}
		display `b_treatment_y1p'
		restore
		
		preserve
		keep if abs(b_y1_treat_y2_treat)> abs(`=b_y1_treat_y2_treatb') 
		if _N==0{
			local b_y1_treat_y2_treatp= 0.001
			}
		else {
			local b_y1_treat_y2_treatp = _N / `num' 
			}
		display `b_y1_treat_y2_treatp'
		restore
		
		preserve
		gen dif=b_treatment-b_treatment_y1
		tab dif
		keep if abs(dif)>abs(`=difb')
		scalar eqtest= _N/`num'
		estadd scalar eqtest = _N/`num'
		display `eqtest'
		restore
		eststo treat_complete_`x'

		preserve
		gen dif123=b_treatment_y1+b_y1_treat_y2_treat-b_treatment
		tab dif123
		keep if abs(dif123)>abs(`=difb123')
		scalar eqtest2= _N/`num'
		estadd scalar eqtest2 = _N/`num'
		display `eqtest2'
		restore
		eststo treat_complete_`x'

		preserve
		gen dif13=b_treatment_y1+b_y1_treat_y2_treat
		keep if abs(dif13)>abs(`=difb13')
		scalar eqtest3= _N/`num'
		estadd scalar eqtest3 = _N/`num'
		display `eqtest3'
		restore
		eststo treat_complete_`x'

	add_pval, results(treat_complete_`x') pval1(`b_treatmentp') pval2(`b_treatment_y1p') pval3(`b_y1_treat_y2_treatp') indvar1(treatment) indvar2( treatment_y1) indvar3( y1_treat_y2_treat) // From the program above
	eststo treat_complete_`x'
	
	}



*************************************************************
* Draw table
*************************************************************

	local file interaction_complete_`var'_simple_rand

	# delimit ;
	esttab treat_complete_t treat_complete_c treat_complete_a
		using "${TP_PAPER_OUTPUT}/tex/input/`file'_input.tex", 
		keep(treatment treatment_y1 y1_treat_y2_treat)
		order (treatment_y1 treatment y1_treat_y2_treat)
	cells(b(fmt(%12.3f) star)
	se(fmt(%12.3f) par)
	pval(fmt(%12.3f) par([ ]))
	)
		
	collabels(none)				
	coeflabels(treatment "Y2 Treatment $(\beta_2)$" treatment_y1 "Y1 Treatment $(\beta_1)$" y1_treat_y2_treat "Y1 AND Y2 Treatment $(\beta_3)$")
	stardrop(treatment treatment_y1 y1_treat_y2_treat)
	mtitles("Total" "Current" "Arrears") // Column headings
					
		stats( N  eqtest eqtest3 ymean ,
			labels(
				"N"
			"$\beta_1 = \beta_2$"
				"$\beta_1 + \beta_3 = 0$"
				"Mean growth in controls"
			)	
			fmt(
				"%12.0f" 
				"%12.3f"
				"%12.3f"
				"%12.3f"
				)
		)	
		
		label // Use Variable Labels
		
		
		booktabs // a nicer version of tables
		substitute("<" "$<$")
		fragment
		replace
		;

	# delimit cr
	eststo clear

	** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

	set more off

	** WRITE TABLE NOTE

	file open tablenote using "${TP_PAPER_OUTPUT}/tex/notes/`file'_notes.txt", write replace

	file write tablenote "OLS regessions of log of tax revenue on Y1/Y2 treatment interactions"
	file write tablenote " The unit of observation is a circle, as defined at the time of randomization."
	file write tablenote " Specification controls for baseline values."
	file write tablenote " Robust standard errors in parentheses."
	file write tablenote " Standard errors are clustered by circle."
	file write tablenote " Randomization inference based p-values in brackets."
	file write tablenote " RI p-values displayed for tests of equality of coefficients."

	file close tablenote

	texout2 "${TP_PAPER_OUTPUT}/tex/`file'", ///
	  input("input/`file'_input") notes("notes/`file'_notes")

	compiletex "${TP_PAPER_OUTPUT}/tex/`file'.tex", ///
	  out("..") aux("auxdir/")  

}

	erase y2_data_rand_inf_recov_tot_t.dta
	erase y2_data_rand_inf_recov_tot_c.dta
	erase y2_data_rand_inf_recov_tot_a.dta
